This patch reverses the standard resv logic for channels, making any
channel not listed in a resv{} block banned from the server.

To install:
$ cd /path/to/ircd-hybrid-7.0rc9
$ patch -p1 </path/to/7rc9-reversejupe.diff

- W. Campbell (Hwy)
diff -uNrd ircd-hybrid-7.0rc9.dist/doc/example.conf ircd-hybrid-7.0rc9/doc/example.conf
--- ircd-hybrid-7.0rc9.dist/doc/example.conf	Wed Oct 30 12:44:51 2002
+++ ircd-hybrid-7.0rc9/doc/example.conf	Wed Apr 16 20:49:18 2003
@@ -440,14 +440,26 @@
 };
 
 /* resv {}: nicks and channels users may not use/join (OLD Q:) */
+/* NOTE:  If this line is here, the server was patched to have reverse
+** logic for resv{}.  In this case, any channels NOT listed here are
+** blocked from users.  If 'oper_pass_resv' is set to yes in the channels{}
+** block, opers can join any channel.  If not, then opers are restricted
+** the same way.
+**
+** Nick logic remains the same.  Anything listed in a resv{} will prevent
+** that nick from being used.
+*/
 resv {
         /* reason: the reason for the proceeding resv's */
         reason = "There are no services on this network";
 
-	/* resv: the nicks and channels users may not join/use */
+	/* resv: the nicks users may not use */
 	nick = "nickserv";
 	nick = "chanserv";
+
+	/* resv: the channels users MAY use, all others are blocked */
 	channel = "#services";
+	channel = "#network";
 
 	/* resv: wildcard masks are also supported in nicks only */
 	reason = "Clone bots";
diff -uNrd ircd-hybrid-7.0rc9.dist/include/patchlevel.h ircd-hybrid-7.0rc9/include/patchlevel.h
--- ircd-hybrid-7.0rc9.dist/include/patchlevel.h	Thu Feb 20 00:41:04 2003
+++ ircd-hybrid-7.0rc9/include/patchlevel.h	Wed Apr 16 20:51:41 2003
@@ -23,5 +23,5 @@
  */
 
 #ifndef PATCHLEVEL
-#define PATCHLEVEL   "hybrid-7.0rc9"
+#define PATCHLEVEL   "hybrid-7.0rc9+revjupe"
 #endif
diff -uNrd ircd-hybrid-7.0rc9.dist/modules/m_join.c ircd-hybrid-7.0rc9/modules/m_join.c
--- ircd-hybrid-7.0rc9.dist/modules/m_join.c	Sat Feb  1 15:11:45 2003
+++ ircd-hybrid-7.0rc9/modules/m_join.c	Wed Apr 16 20:44:22 2003
@@ -180,13 +180,13 @@
       }
       
       /* see if its resv'd */
-      if(find_channel_resv(name) &&
+      if((find_channel_resv(name) == 0) &&
          !(IsOper(source_p) && ConfigChannel.oper_pass_resv))
 	{
 	  sendto_one(source_p, form_str(ERR_UNAVAILRESOURCE),
 		     me.name, source_p->name, name);
           sendto_realops_flags(FLAGS_SPY, L_ALL,
-                   "User %s (%s@%s) is attempting to join locally juped channel %s",
+                   "User %s (%s@%s) is attempting to join blocked channel %s",
                    source_p->name, source_p->username, source_p->host, name);
 	  continue;
 	}
diff -uNrd ircd-hybrid-7.0rc9.dist/src/channel.c ircd-hybrid-7.0rc9/src/channel.c
--- ircd-hybrid-7.0rc9.dist/src/channel.c	Thu Feb  6 03:46:01 2003
+++ ircd-hybrid-7.0rc9/src/channel.c	Wed Apr 16 20:44:55 2003
@@ -1243,7 +1243,7 @@
 can_send(struct Channel *chptr, struct Client *source_p)
 {
   if(MyClient(source_p) &&
-     (find_channel_resv(chptr->chname) &&
+     ((find_channel_resv(chptr->chname) == 0) &&
       !(IsOper(source_p)) && ConfigChannel.oper_pass_resv))
     return (CAN_SEND_NO);
     
